==> adx-center-api-0.0.20-sources.jar: cn/com/duiba/tuia/adx/center/api/dto/AdvertisingSpaceStyleDetailDto.java <==
package cn.com.duiba.tuia.adx.center.api.dto;

import org.apache.commons.lang.builder.ToStringBuilder;

import java.io.Serializable;

/**
 * @author shenjiaqing
 * @description
 * @data 2019/11/20
 */
public class AdvertisingSpaceStyleDetailDto implements Serializable {

    /** 样式ID **/
    private Long id;

    /** 广告位类型ID **/
    private Long adTypeId;

    /** 样式名称 **/
    private String adStyleName;

    /** 最少标题字数 **/
    private Integer titleMinNum;

    /** 最多标题字数 **/
    private Integer titleMaxNum;

    /** 最少描述字数 **/
    private Integer descriptionMinNum;

    /** 最多描述字数 **/
    private Integer descriptionMaxNum;

    /** ADX样式ID **/
    private String templateId;

    /** 素材数量 **/
    private Integer num;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAdTypeId() {
        return adTypeId;
    }

    public void setAdTypeId(Long adTypeId) {
        this.adTypeId = adTypeId;
    }

    public String getAdStyleName() {
        return adStyleName;
    }

    public void setAdStyleName(String adStyleName) {
        this.adStyleName = adStyleName;
    }

    public Integer getTitleMinNum() {
        return titleMinNum;
    }

    public void setTitleMinNum(Integer titleMinNum) {
        this.titleMinNum = titleMinNum;
    }

    public Integer getTitleMaxNum() {
        return titleMaxNum;
    }

    public void setTitleMaxNum(Integer titleMaxNum) {
        this.titleMaxNum = titleMaxNum;
    }

    public Integer getDescriptionMinNum() {
        return descriptionMinNum;
    }

    public void setDescriptionMinNum(Integer descriptionMinNum) {
        this.descriptionMinNum = descriptionMinNum;
    }

    public Integer getDescriptionMaxNum() {
        return descriptionMaxNum;
    }

    public void setDescriptionMaxNum(Integer descriptionMaxNum) {
        this.descriptionMaxNum = descriptionMaxNum;
    }

    public String getTemplateId() {
        return templateId;
    }

    public void setTemplateId(String templateId) {
        this.templateId = templateId;
    }

    public Integer getNum() {
        return num;
    }

    public void setNum(Integer num) {
        this.num = num;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }

}

==> adx-center-api-0.1.43-20250728.060414-9-sources.jar: cn/com/duiba/tuia/adx/center/api/dto/AdvertisingSpaceStyleDetailDto.java <==
package cn.com.duiba.tuia.adx.center.api.dto;

import org.apache.commons.lang.builder.ToStringBuilder;

import java.io.Serializable;

/**
 * @author shenjiaqing
 * @description
 * @data 2019/11/20
 */
public class AdvertisingSpaceStyleDetailDto implements Serializable {

    /** 样式ID **/
    private Long id;

    /** 广告位类型ID **/
    private Long adTypeId;

    /** 样式名称 **/
    private String adStyleName;

    /** 最少标题字数 **/
    private Integer titleMinNum;

    /** 最多标题字数 **/
    private Integer titleMaxNum;

    /** 最少描述字数 **/
    private Integer descriptionMinNum;

    /** 最多描述字数 **/
    private Integer descriptionMaxNum;

    /** 号召口令最少描述字数 **/
    private Integer callWordsMin;

    /** 号召口令最多描述字数 **/
    private Integer callWordsMax;

    public Integer getCallWordsMin() {
        return callWordsMin;
    }

    public void setCallWordsMin(Integer callWordsMin) {
        this.callWordsMin = callWordsMin;
    }

    public Integer getCallWordsMax() {
        return callWordsMax;
    }

    public void setCallWordsMax(Integer callWordsMax) {
        this.callWordsMax = callWordsMax;
    }

    /** ADX样式ID **/
    private String templateId;

    /** 素材数量 **/
    private Integer num;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAdTypeId() {
        return adTypeId;
    }

    public void setAdTypeId(Long adTypeId) {
        this.adTypeId = adTypeId;
    }

    public String getAdStyleName() {
        return adStyleName;
    }

    public void setAdStyleName(String adStyleName) {
        this.adStyleName = adStyleName;
    }

    public Integer getTitleMinNum() {
        return titleMinNum;
    }

    public void setTitleMinNum(Integer titleMinNum) {
        this.titleMinNum = titleMinNum;
    }

    public Integer getTitleMaxNum() {
        return titleMaxNum;
    }

    public void setTitleMaxNum(Integer titleMaxNum) {
        this.titleMaxNum = titleMaxNum;
    }

    public Integer getDescriptionMinNum() {
        return descriptionMinNum;
    }

    public void setDescriptionMinNum(Integer descriptionMinNum) {
        this.descriptionMinNum = descriptionMinNum;
    }

    public Integer getDescriptionMaxNum() {
        return descriptionMaxNum;
    }

    public void setDescriptionMaxNum(Integer descriptionMaxNum) {
        this.descriptionMaxNum = descriptionMaxNum;
    }

    public String getTemplateId() {
        return templateId;
    }

    public void setTemplateId(String templateId) {
        this.templateId = templateId;
    }

    public Integer getNum() {
        return num;
    }

    public void setNum(Integer num) {
        this.num = num;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }

}
